@@ -23,13 +23,13 @@ def get_models():
     resp = requests.get(url, headers=HEADERS)
     resp = _format_http_response(resp)
     for model in resp['body']:
-        model = Model(
+        m = Model(
             model_id=model['id'],
             model_spec=model['model_spec'],
             supp_id = model['supp_id'],
             description=model['description']
         )
-        models[model['id']] = model
+        models[model['id']] = m
 
 
 def get_incantations():
@@ -37,14 +37,14 @@ def get_incantations():
     resp = requests.get(url, headers=HEADERS)
     resp = _format_http_response(resp)
     for incantation in resp['body']:
-        incantation = Incantation(
+        inc = Incantation(
             incantation_id=incantation['id'],
             title=incantation['title'],
             text=incantation['text'],
             supp_id=incantation['supp_id'],
             description=incantation['description']
         )
-        incantations[incantation['id']] = incantation
+        incantations[incantation['id']] = inc
 
 
 def init(api_key: str):
@@ -173,13 +173,13 @@ class Model:
         resp = _format_http_response(requests.get(url, headers=HEADERS))
         instances = {}
         for instance in resp['body']:
-            instance = ModelInstance(
+            inst = ModelInstance(
                 model_id=instance['model_id'],
                 supp_id=instance['supp_id'],
                 description=instance['description'],
                 instance_id=instance['id']
             )
-            instances[instance['id']] = instance
+            instances[instance['id']] = inst
         return instances
 
 
@@ -191,7 +191,7 @@ class ModelInstance:
         self.model_id = model_id
         self.chat_history = []
         self.chat_history = self.get_chat_history()
-        self.is_deployed = self.instance_id not in models[self.model_id].model_instances
+        self.is_deployed = self.instance_id is not None
 
     def get_chat_history(self):
         # get chat history interactions with pagination
